translate.storage.xpi

Package translate :: Package storage :: Module xpi |
[hide private]
[frames] | no frames]

# Module xpi

source code

module for accessing mozilla xpi packages

Classes | [hide private]
| FixedStringIO
| CatchPotentialOutput catches output if there has been, before closing
| ZipFileCatcher a ZipFile that calls any methods its instructed to before closing (useful for catching stream output)
| XpiFile

Functions | [hide private]
_commonprefix(itemlist) | source code
rememberchanged(self, method) | source code

Imports: zipfile, os, StringIO, re, zipfileext, ZipFileBase, wStringIO, NamedStringInput, NamedStringOutput